function r = FDotGradFx(c, l)
    % returns the scalar product between the function associated to the
    % node of center c and side size l and the x derivative of the basis F function 
    rg = intVsG( 1/(2*l^2), (1.5/l - c(1)/l^2), 0.5*(1.5 - c(1)/l)^2, c(1) - 1.5*l, c(1) - 0.5*l) ...
        + intVsG( -1/(l^2),  2*c(1)/l^2, (0.75 - (c(1)/l)^2), c(1) - 0.5*l, c(1) + 0.5*l) ...
        + intVsG( 1/(2*l^2), -(1.5/l + c(1)/l^2), 0.5*(1.5 + c(1)/l)^2, c(1) + 0.5*l, c(1) + 1.5*l);
    
    rh = intVsH( 1/(2*l^2), (1.5/l - c(2)/l^2), 0.5*(1.5 - c(2)/l)^2, c(2) - 1.5*l, c(2) - 0.5*l) ...
        + intVsH( -1/(l^2),  2*c(2)/l^2, (0.75 - (c(2)/l)^2), c(2) - 0.5*l, c(2) + 0.5*l) ...
        + intVsH( 1/(2*l^2), -(1.5/l + c(2)/l^2), 0.5*(1.5 + c(2)/l)^2, c(2) + 0.5*l, c(2) + 1.5*l);
    
    r = (rg * rh)/l^2;


    function s = intVsG(a,b,c,x1, x2)
        % G(x) = 1.5 + x    if -1.5 <= x <= -0.5
        %        -2x        if -0.5 <= x <= 0.5
        %        x - 1.5    if  0.5 <= x <= 1.5
        %        0          otherwise
        % returns the integral of (ax^2 + bx + c) * G(x) between x1 and x2.
        s = part1( mapTo(x1, -1.5, -0.5), mapTo(x2, -1.5, -0.5)) ...
            + part2( mapTo(x1, -0.5, 0.5), mapTo(x2, -0.5, 0.5)) ...
            + part3( mapTo(x1, 0.5, 1.5), mapTo(x2, 0.5, 1.5)) ;
        
        function t = part1(t1, t2)
            % (ax^2 + bx + c) * (x + 1.5)
            C = conv([a b c], [0 1 1.5]);
            t = intPoly(C(1), C(2), C(3), C(4), C(5), t1, t2);
        end
        function t = part2(t1, t2)
            % (ax^2 + bx + c) * (-2x)
            C = conv([a b c], [0 -2 0]);
            t = intPoly(C(1), C(2), C(3), C(4), C(5), t1, t2);
        end
        function t = part3(t1, t2)
            % (ax^2 + bx + c) * (x - 1.5)
            C = conv([a b c], [0 1 -1.5]);
            t = intPoly(C(1), C(2), C(3), C(4), C(5), t1, t2);
        end
    end

    function s = intVsH(a,b,c,y1, y2)
        % H(y) = 0.5*(y+1.5)^2    if -1.5 <= y <= -0.5
        %        0.5 - y^2        if -0.5 <= y <= 0.5
        %        0.5*(y-1.5)^2    if  0.5 <= y <= 1.5
        %        0          otherwise
        % returns the integral of (ay^2 + by + c) * H(x) between y1 and y2.
        s = part1( mapTo(y1, -1.5, -0.5), mapTo(y2, -1.5, -0.5)) ...
            + part2( mapTo(y1, -0.5, 0.5), mapTo(y2, -0.5, 0.5)) ...
            + part3( mapTo(y1, 0.5, 1.5), mapTo(y2, 0.5, 1.5)) ;
        
        function t = part1(t1, t2)
            % (ay^2 + by + c) * 0.5*(y+1.5)^2
            C = conv([a b c], [0.5 1.5 9/8]);
            t = intPoly(C(1), C(2), C(3), C(4), C(5), t1, t2);
        end
        function t = part2(t1, t2)
            % (ay^2 + by + c) * (0.5 - y^2)
            C = conv([a b c], [-1 0 0.75]);
            t = intPoly(C(1), C(2), C(3), C(4), C(5), t1, t2);
        end
        function t = part3(t1, t2)
            % (ay^2 + by + c) * 0.5*(y-1.5)^2
            C = conv([a b c], [0.5 -1.5 9/8]);
            t = intPoly(C(1), C(2), C(3), C(4), C(5), t1, t2);
        end
    end

    function s = intPoly(a,b,c, d, e, x1, x2)
        % returns int(ax^4 + bx^3 + cx^2 + dx + e, x = x1..x2)
        if isequal(x1, x2)
            s = 0;
        else
            s =  (a/5) * (x2^5 - x1^5) + (b/4) * (x2^4 - x1^4) + (c/3) * (x2^3 - x1^3) + (d/2) * (x2^2 - x1^2) + e * (x2 - x1);
        end
    end
    function s = mapTo(x, x1, x2)
        s = max(min(x, x2), x1);
    end
end