close all;
clear all;

% Our shape looks like :
%                                
%                                
%       +----+   +----+                      
%       |    |   |    |             
%       |    |   |    |             
%       |    +---+    |                
%       |             |           
%       |             |           
%       |             |           
%       |             / 
%       |            /            
%       |           /             
%       0          /              
%       .         /              
%        .       /               
%         ..   ..                
%           ...                  
%                               
%                               
%      
for ech = [0.7,0.4,0.2,0.1,0.05,0.01]
for alpha = [0,1,4,10,40,100]


% Circular bottom left part
t = pi:ech:(7*pi/4) ;
t = t';
t = t(2:end);

P = [cos(t), sin(t)];
N_P = [-cos(t), -sin(t)];

% diagonal part
a = sqrt(2)/2;
t = 0:ech/sqrt(2):(2-a) ;
t = t';
t = t(2:end);

P = [P; [a + t, t - a]];
N_P = [N_P; repmat([-a, a], numel(t), 1)];

% left part
t = (2-2*a):ech:3;
t = t';
t = t(2:end);
P = [P; [2*ones(numel(t), 1), t]];
N_P = [N_P; repmat([-1,0], numel(t), 1)];

% top right part
t = 2:-ech:1;
t = t';
t = t(2:end);
P = [P; [t, 3*ones(numel(t), 1)]];
N_P = [N_P; repmat([0, -1], numel(t), 1)];

% right branch of the U
t = 3:-ech:2;
t = t';
t = t(2:end);
P = [P; [1*ones(numel(t), 1), t]];
N_P = [N_P; repmat([1, 0], numel(t), 1)];


% top middle part
t = 1:-ech:0;
t = t';
t = t(2:end);
P = [P; [t, 2*ones(numel(t), 1)]];
N_P = [N_P; repmat([0, -1], numel(t), 1)];

% left branch of the U
t = 2:ech:3;
t = t';
t = t(2:end);
P = [P; [0*ones(numel(t), 1), t]];
N_P = [N_P; repmat([-1, 0], numel(t), 1)];



% top left part
t = 0:-ech:-1;
t = t';
t = t(2:end);
P = [P; [t, 3*ones(numel(t), 1)]];
N_P = [N_P; repmat([0, -1], numel(t), 1)];

% left part
t = 3:-ech:0;
t = t';
t = t(2:end);
P = [P; [-1*ones(numel(t), 1), t]];
N_P = [N_P; repmat([1, 0], numel(t), 1)];

area = 3 + 1 + 1 + 1 + 1 + 1 + (1 + 2*a) + sqrt(2)*(2-a) + (7*pi/4);
area = area / 10; % needless to say, this is a curve length, not an area.


P = P/10 + 0.4;

[n_p, ~] = size(P);
w = ones(n_p);
w = w';

S = Poisson2DSolver(P, N_P, w, 4, alpha);



figure(1);
hold on;
scatter(P(:,1), P(:,2));
S.T.plot();
%S.T.plotV();
[X,Y,Z] = S.plotContour();
fprintf('\n');
axis([0,1,0,1]);
axis square;
hold off;
save(sprintf('data/final_a%d_ech%e.mat', alpha, ech), 'S', 'X', 'Y', 'Z');
end;
end;
